@@ -1,24 +1,25 @@
 """The API for publishing messages and consuming from message queues."""
-from __future__ import absolute_import
+
 
 import inspect
 import logging
 
-from twisted.internet import reactor, defer
 import crochet
+from twisted.internet import defer, reactor
 
-from . import exceptions, config
-from .signals import pre_publish_signal, publish_signal, publish_failed_signal
-from .message import (
-    Message,
-    SEVERITIES,
-    loads,
+from . import config, exceptions
+from .message import (  # noqa: F401
     dumps,
+    loads,
+    Message,
     SERIALIZED_MESSAGE_SCHEMA,
-)  # noqa: F401
+    SEVERITIES,
+)
+from .signals import pre_publish_signal, publish_failed_signal, publish_signal
 from .twisted import service
 from .twisted.consumer import Consumer  # noqa: F401
 
+
 _log = logging.getLogger(__name__)
 
 
@@ -317,7 +318,7 @@ def publish(message, exchange=None, timeout=30):
     except crochet.TimeoutError:
         eventual_result.cancel()
         wrapper = exceptions.PublishTimeout(
-            "Publishing timed out after waiting {} seconds.".format(timeout)
+            f"Publishing timed out after waiting {timeout} seconds."
         )
         publish_failed_signal.send(publish, message=message, reason=wrapper)
         raise wrapper
