@@ -17,16 +17,15 @@
 
 import datetime
 import json
-import unittest
+from unittest import mock, TestCase
 
 import jsonschema
-import mock
 import pika
 
-from fedora_messaging import message, exceptions
+from fedora_messaging import exceptions, message
 
 
-class GetMessageTests(unittest.TestCase):
+class GetMessageTests(TestCase):
     """Tests for the :func:`fedora_messaging.message.get_message` function."""
 
     def test_missing_severity(self):
@@ -57,7 +56,7 @@ class GetMessageTests(unittest.TestCase):
         self.assertIsInstance(received_msg, message.Message)
 
 
-class MessageDumpsTests(unittest.TestCase):
+class MessageDumpsTests(TestCase):
     """Tests for the :func:`fedora_messaging.message.dumps` function."""
 
     def test_proper_message(self):
@@ -131,7 +130,7 @@ class MessageDumpsTests(unittest.TestCase):
         self.assertRaises(exceptions.ValidationError, message.dumps, messages)
 
 
-class MessageLoadsTests(unittest.TestCase):
+class MessageLoadsTests(TestCase):
     """Tests for the :func:`fedora_messaging.message.loads` function."""
 
     def test_proper_json(self):
@@ -196,13 +195,15 @@ class MessageLoadsTests(unittest.TestCase):
         self.assertRaises(exceptions.ValidationError, message.loads, message_json)
 
     def test_missing_queue(self):
-        """Assert message without queue is returned and warning is printed."""
+        """Assert message without queue is accepted and the queue is set to None."""
         message_json = (
             '{"topic": "test topic", "headers": {"fedora_messaging_schema": '
             '"base.message", "fedora_messaging_severity": 30}, "id": "test id", '
             '"body": {"test_key": "test_value"}}'
         )
-        self.assertRaises(exceptions.ValidationError, message.loads, message_json)
+        messages = message.loads(message_json)
+        test_message = messages[0]
+        self.assertIsNone(test_message.queue)
 
     def test_missing_topic(self):
         """Assert proper exception is raised when topic is missing."""
@@ -232,7 +233,7 @@ class MessageLoadsTests(unittest.TestCase):
         self.assertRaises(exceptions.ValidationError, message.loads, message_json)
 
 
-class MessageTests(unittest.TestCase):
+class MessageTests(TestCase):
     """Tests for the :class:`fedora_messaging.message.Message` class."""
 
     def test_summary(self):
@@ -382,30 +383,6 @@ class MessageTests(unittest.TestCase):
         """The flatpaks attribute must exist and be a list."""
         self.assertEqual(message.Message().flatpaks, [])
 
-    @mock.patch("fedora_messaging.message.warnings")
-    def test_body_deprecation_setter(self, mock_warning):
-        """Assert a deprecation warning is printed on _body setter usage."""
-        m = message.Message(body={})
-        m._body["old"] = "interface"
-
-        mock_warning.warn.assert_called_once_with(
-            "The '_body' property has been renamed to 'body'.",
-            DeprecationWarning,
-            stacklevel=2,
-        )
-
-    @mock.patch("fedora_messaging.message.warnings")
-    def test_body_deprecation_getter(self, mock_warning):
-        """Assert a deprecation warning is printed on _body getter usage."""
-        m = message.Message(body={"old": "interface"})
-        self.assertEqual(m._body["old"], "interface")
-
-        mock_warning.warn.assert_called_once_with(
-            "The '_body' property has been renamed to 'body'.",
-            DeprecationWarning,
-            stacklevel=2,
-        )
-
     def test_topic_prefix(self):
         """Assert the topic prefix is used in the encoded routing key."""
         with mock.patch.dict(message.config.conf, {"topic_prefix": "prefix"}):
@@ -454,7 +431,7 @@ class CustomMessage(message.Message):
 
 
 @mock.patch.dict(message._class_to_schema_name, {CustomMessage: "custom_id"})
-class CustomMessageTests(unittest.TestCase):
+class CustomMessageTests(TestCase):
     """Tests for a Message subclass that provides filter headers"""
 
     def test_usernames(self):
@@ -498,7 +475,7 @@ class CustomMessageTests(unittest.TestCase):
         self.assertIn("fedora_messaging_flatpak_hexchat", msg._headers)
 
 
-class ClassRegistryTests(unittest.TestCase):
+class ClassRegistryTests(TestCase):
     """Tests for the :func:`fedora_messaging.message.load_message_classes`."""
 
     def test_load_message_name_to_class(self):
